@@ -4,6 +4,7 @@ import json
 import operator as op
 import warnings
 from collections import defaultdict
+from dataclasses import dataclass
 from datetime import datetime
 from functools import cached_property
 from typing import (
@@ -33,6 +34,7 @@ from cognite.client.utils._auxiliary import (
     local_import,
     to_camel_case,
 )
+from cognite.client.utils._identifier import Identifier
 from cognite.client.utils._pandas_helpers import concat_dataframes_with_nullable_int_cols
 
 ALL_SORTED_DP_AGGS = sorted(
@@ -69,6 +71,28 @@ except ImportError:  # pragma no cover
     NUMPY_IS_AVAILABLE = False
 
 
+@dataclass(frozen=True)
+class LatestDatapointQuery:
+    """Parameters describing a query for the latest datapoint from a time series.
+
+    Note:
+        Pass either ID or external ID.
+
+    Args:
+        id (Optional[int]): The internal ID of the time series to query.
+        external_id (Optional[str]): The external ID of the time series to query.
+        before (Union[None, int, str, datetime]): Get latest datapoint before this time. None means 'now'.
+    """
+
+    id: Optional[int] = None
+    external_id: Optional[str] = None
+    before: Union[None, int, str, datetime] = None
+
+    def __post_init__(self) -> None:
+        # Ensure user have just specified one of id/xid:
+        Identifier.of_either(self.id, self.external_id)
+
+
 class Datapoint(CogniteResource):
     """An object representing a datapoint.
 
