@@ -95,11 +95,11 @@ class TimeSeries(CogniteResource):
 
         identifier = Identifier.load(self.id, self.external_id).as_dict()
         dps = self._cognite_client.time_series.data.retrieve(
-            **identifier, start=MIN_TIMESTAMP_MS, end=MAX_TIMESTAMP_MS, aggregates="count", granularity="100d"
+            **identifier, start=MIN_TIMESTAMP_MS, end=MAX_TIMESTAMP_MS + 1, aggregates="count", granularity="100d"
         )
         return sum(dps.count)
 
-    def latest(self, before: Union[int, str, datetime] = None) -> Optional["Datapoint"]:  # noqa: F821
+    def latest(self, before: Union[int, str, datetime] = None) -> Optional["Datapoint"]:
         """Returns the latest datapoint in this time series. If empty, returns None.
 
         Returns:
@@ -110,7 +110,7 @@ class TimeSeries(CogniteResource):
             return dps[0]
         return None
 
-    def first(self) -> Optional["Datapoint"]:  # noqa: F821
+    def first(self) -> Optional["Datapoint"]:
         """Returns the first datapoint in this time series. If empty, returns None.
 
         Returns:
@@ -118,13 +118,13 @@ class TimeSeries(CogniteResource):
         """
         identifier = Identifier.load(self.id, self.external_id).as_dict()
         dps = self._cognite_client.time_series.data.retrieve(
-            **identifier, start=MIN_TIMESTAMP_MS, end=MAX_TIMESTAMP_MS, limit=1
+            **identifier, start=MIN_TIMESTAMP_MS, end=MAX_TIMESTAMP_MS + 1, limit=1
         )
         if dps:
             return dps[0]
         return None
 
-    def asset(self) -> "Asset":  # noqa: F821
+    def asset(self) -> "Asset":
         """Returns the asset this time series belongs to.
 
         Returns:
