@@ -3,13 +3,13 @@ import time
 from enum import Enum
 from typing import TYPE_CHECKING, Dict, Optional, Union, cast
 
-from cognite.client import utils
 from cognite.client.data_classes._base import CogniteFilter, CogniteResource, CogniteResourceList
 from cognite.client.data_classes.transformations.common import (
     DataModelInstances,
     RawTable,
     SequenceRows,
     TransformationDestination,
+    _load_destination_dct,
 )
 
 if TYPE_CHECKING:
@@ -253,16 +253,7 @@ class TransformationJob(CogniteResource):
     def _load(cls, resource: Union[Dict, str], cognite_client: "CogniteClient" = None) -> "TransformationJob":
         instance = super(TransformationJob, cls)._load(resource, cognite_client)
         if isinstance(instance.destination, Dict):
-            snake_dict = {utils._auxiliary.to_snake_case(key): value for (key, value) in instance.destination.items()}
-            destination_type = snake_dict.pop("type")
-            if destination_type == "raw":
-                instance.destination = RawTable(**snake_dict)
-            elif destination_type == "data_model_instances":
-                instance.destination = DataModelInstances(**snake_dict)
-            elif destination_type == "sequence_rows":
-                instance.destination = SequenceRows(**snake_dict)
-            else:
-                instance.destination = TransformationDestination(destination_type)
+            instance.destination = _load_destination_dct(instance.destination)
         return instance
 
     def __hash__(self) -> int:
