@@ -33,7 +33,7 @@ class TasksSummary:
         str_format_element_fn: Optional[Callable] = None,
     ) -> None:
         if not self.exceptions:
-            return
+            return None
         task_unwrap_fn = (lambda x: x) if task_unwrap_fn is None else task_unwrap_fn
         if task_list_element_unwrap_fn is not None:
             successful = []
@@ -110,7 +110,9 @@ def collect_exc_info_and_raise(
 def execute_tasks_concurrently(
     func: Callable, tasks: Union[Sequence[Tuple], List[Dict]], max_workers: int
 ) -> TasksSummary:
-    assert max_workers > 0, "Number of workers should be >= 1, was {}".format(max_workers)
+    if max_workers < 1:
+        raise RuntimeError(f"Number of workers should be >= 1, was {max_workers}")
+
     with ThreadPoolExecutor(max_workers) as p:
         futures = []
         for task in tasks:
